## Dataset Attribution
This dataset was created by Wang et al and is licensed under the MIT License. 

- Original Source: [github.com](https://github.com/EternityYW/BiasEval-LLM-MentalHealth/)
- License: [https://mit-license.org/](https://mit-license.org/)
- Changes Made: Only the dreaddit portion of their repository is stored here.
